@@ -4,8 +4,10 @@
 # author: ScCcWe
 # time: 2022/3/4 3:39 下午
 from pymysqldao.dao.baseDao import BaseDao
+from pymysqldao.dao.databaseDao import DatabaseDao
 
 # 最外层的__all__ 可以理解为给大家使用的接口
 __all__ = [
     "BaseDao",
+    "DatabaseDao",
 ]
